@@ -2,8 +2,8 @@
 /* Generated data (by glib-mkenums) */
 
 #include "e-book-enumtypes.h"
-/* enumerations from "/usr/src/ports/evolution-data-server/evolution-data-server-3.18.3-1.x86_64/src/evolution-data-server-3.18.3/addressbook/libebook/e-book-types.h" */
-#include "/usr/src/ports/evolution-data-server/evolution-data-server-3.18.3-1.x86_64/src/evolution-data-server-3.18.3/addressbook/libebook/e-book-types.h"
+/* enumerations from "/usr/src/ports/evolution-data-server/evolution-data-server-3.20.6-1.i686/src/evolution-data-server-3.20.6/addressbook/libebook/e-book-types.h" */
+#include "/usr/src/ports/evolution-data-server/evolution-data-server-3.20.6-1.i686/src/evolution-data-server-3.20.6/addressbook/libebook/e-book-types.h"
 
 GType
 e_book_status_get_type (void)
