@@ -2,8 +2,8 @@
 /* Generated data (by glib-mkenums) */
 
 #include "camel-enumtypes.h"
-/* enumerations from "/usr/src/ports/evolution-data-server/evolution-data-server-3.18.3-1.x86_64/src/evolution-data-server-3.18.3/camel/camel-enums.h" */
-#include "/usr/src/ports/evolution-data-server/evolution-data-server-3.18.3-1.x86_64/src/evolution-data-server-3.18.3/camel/camel-enums.h"
+/* enumerations from "/usr/src/ports/evolution-data-server/evolution-data-server-3.20.6-1.x86_64/src/evolution-data-server-3.20.6/camel/camel-enums.h" */
+#include "/usr/src/ports/evolution-data-server/evolution-data-server-3.20.6-1.x86_64/src/evolution-data-server-3.20.6/camel/camel-enums.h"
 
 GType
 camel_authentication_result_get_type (void)
@@ -721,6 +721,9 @@ camel_store_flags_get_type (void)
 			{ CAMEL_STORE_CAN_DELETE_FOLDERS_AT_ONCE,
 			  "CAMEL_STORE_CAN_DELETE_FOLDERS_AT_ONCE",
 			  "can-delete-folders-at-once" },
+			{ CAMEL_STORE_SUPPORTS_INITIAL_SETUP,
+			  "CAMEL_STORE_SUPPORTS_INITIAL_SETUP",
+			  "supports-initial-setup" },
 			{ 0, NULL, NULL }
 		};
 		GType the_type = g_flags_register_static (
