@@ -2,8 +2,8 @@
 /* Generated data (by glib-mkenums) */
 
 #include "e-backend-enumtypes.h"
-/* enumerations from "/usr/src/ports/evolution-data-server/evolution-data-server-3.18.3-1.i686/src/evolution-data-server-3.18.3/libebackend/e-backend-enums.h" */
-#include "/usr/src/ports/evolution-data-server/evolution-data-server-3.18.3-1.i686/src/evolution-data-server-3.18.3/libebackend/e-backend-enums.h"
+/* enumerations from "/usr/src/ports/evolution-data-server/evolution-data-server-3.20.6-1.x86_64/src/evolution-data-server-3.20.6/libebackend/e-backend-enums.h" */
+#include "/usr/src/ports/evolution-data-server/evolution-data-server-3.20.6-1.x86_64/src/evolution-data-server-3.20.6/libebackend/e-backend-enums.h"
 
 GType
 e_authentication_session_result_get_type (void)
