@@ -2,8 +2,8 @@
 /* Generated data (by glib-mkenums) */
 
 #include "e-source-enumtypes.h"
-/* enumerations from "/usr/src/ports/evolution-data-server/evolution-data-server-3.18.3-1.i686/src/evolution-data-server-3.18.3/libedataserver/e-source-enums.h" */
-#include "/usr/src/ports/evolution-data-server/evolution-data-server-3.18.3-1.i686/src/evolution-data-server-3.18.3/libedataserver/e-source-enums.h"
+/* enumerations from "/usr/src/ports/evolution-data-server/evolution-data-server-3.20.6-1.i686/src/evolution-data-server-3.20.6/libedataserver/e-source-enums.h" */
+#include "/usr/src/ports/evolution-data-server/evolution-data-server-3.20.6-1.i686/src/evolution-data-server-3.20.6/libedataserver/e-source-enums.h"
 
 GType
 e_mdn_response_policy_get_type (void)
@@ -289,6 +289,38 @@ e_source_weather_units_get_type (void)
 	return the_type__volatile;
 }
 
+GType
+e_source_mail_composition_reply_style_get_type (void)
+{
+	static volatile gsize the_type__volatile = 0;
+
+	if (g_once_init_enter (&the_type__volatile)) {
+		static const GEnumValue values[] = {
+			{ E_SOURCE_MAIL_COMPOSITION_REPLY_STYLE_DEFAULT,
+			  "E_SOURCE_MAIL_COMPOSITION_REPLY_STYLE_DEFAULT",
+			  "default" },
+			{ E_SOURCE_MAIL_COMPOSITION_REPLY_STYLE_QUOTED,
+			  "E_SOURCE_MAIL_COMPOSITION_REPLY_STYLE_QUOTED",
+			  "quoted" },
+			{ E_SOURCE_MAIL_COMPOSITION_REPLY_STYLE_DO_NOT_QUOTE,
+			  "E_SOURCE_MAIL_COMPOSITION_REPLY_STYLE_DO_NOT_QUOTE",
+			  "do-not-quote" },
+			{ E_SOURCE_MAIL_COMPOSITION_REPLY_STYLE_ATTACH,
+			  "E_SOURCE_MAIL_COMPOSITION_REPLY_STYLE_ATTACH",
+			  "attach" },
+			{ E_SOURCE_MAIL_COMPOSITION_REPLY_STYLE_OUTLOOK,
+			  "E_SOURCE_MAIL_COMPOSITION_REPLY_STYLE_OUTLOOK",
+			  "outlook" },
+			{ 0, NULL, NULL }
+		};
+		GType the_type = g_enum_register_static (
+			g_intern_static_string ("ESourceMailCompositionReplyStyle"),
+			values);
+		g_once_init_leave (&the_type__volatile, the_type);
+	}
+	return the_type__volatile;
+}
+
 
 /* Generated data ends here */
 
